@@ -1,6 +1,7 @@
 <?php
+
 /**
- * @file views-view-unformatted.tpl.php
+ * @file
  * Default simple view template to display a list of rows.
  *
  * @ingroup views_templates
@@ -10,7 +11,7 @@
   <h3><?php print $title; ?></h3>
 <?php endif; ?>
 <?php foreach ($rows as $id => $row): ?>
-  <div class="<?php print $classes_array[$id]; ?>">
+  <div <?php if ($classes_array[$id]) { print 'class="' . $classes_array[$id] .'"';  } ?>>
     <?php print $row; ?>
   </div>
 <?php endforeach; ?>
